@@ -13,11 +13,12 @@ import (
 	"text/template"
 	"time"
 
-	"github.com/google/go-github/v63/github"
+	"github.com/google/go-github/v64/github"
 	"github.com/goreleaser/goreleaser/v2/internal/artifact"
 	"github.com/goreleaser/goreleaser/v2/internal/testctx"
 	"github.com/goreleaser/goreleaser/v2/internal/testlib"
 	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -272,9 +273,9 @@ func TestGitHubChangelog(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/compare/v1.0.0...v1.1.0" {
 			r, err := os.Open("testdata/github/compare.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 		if r.URL.Path == "/rate_limit" {
@@ -317,9 +318,9 @@ func TestGitHubReleaseNotes(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/releases/generate-notes" {
 			r, err := os.Open("testdata/github/releasenotes.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 		if r.URL.Path == "/rate_limit" {
@@ -387,9 +388,9 @@ func TestGitHubCloseMilestone(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/milestones" {
 			r, err := os.Open("testdata/github/milestones.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
@@ -434,16 +435,16 @@ func TestGitHubOpenPullRequestCrossRepo(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/pulls" {
 			got, err := io.ReadAll(r.Body)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			var pr github.NewPullRequest
-			require.NoError(t, json.Unmarshal(got, &pr))
-			require.Equal(t, "main", pr.GetBase())
-			require.Equal(t, "someoneelse:something:foo", pr.GetHead())
-			require.Equal(t, testPRTemplate+"\n"+prFooter, pr.GetBody())
+			assert.NoError(t, json.Unmarshal(got, &pr))
+			assert.Equal(t, "main", pr.GetBase())
+			assert.Equal(t, "someoneelse:something:foo", pr.GetHead())
+			assert.Equal(t, testPRTemplate+"\n"+prFooter, pr.GetBody())
 			r, err := os.Open("testdata/github/pull.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
@@ -493,9 +494,9 @@ func TestGitHubOpenPullRequestHappyPath(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/pulls" {
 			r, err := os.Open("testdata/github/pull.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
@@ -536,17 +537,17 @@ func TestGitHubOpenPullRequestNoBaseBranchDraft(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/pulls" {
 			got, err := io.ReadAll(r.Body)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			var pr github.NewPullRequest
-			require.NoError(t, json.Unmarshal(got, &pr))
-			require.Equal(t, "main", pr.GetBase())
-			require.Equal(t, "someone:something:foo", pr.GetHead())
-			require.True(t, pr.GetDraft())
+			assert.NoError(t, json.Unmarshal(got, &pr))
+			assert.Equal(t, "main", pr.GetBase())
+			assert.Equal(t, "someone:something:foo", pr.GetHead())
+			assert.True(t, pr.GetDraft())
 
 			r, err := os.Open("testdata/github/pull.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
@@ -595,9 +596,9 @@ func TestGitHubOpenPullRequestPRExists(t *testing.T) {
 		if r.URL.Path == "/repos/someone/something/pulls" {
 			w.WriteHeader(http.StatusUnprocessableEntity)
 			r, err := os.Open("testdata/github/pull.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
@@ -638,9 +639,9 @@ func TestGitHubOpenPullRequestBaseEmpty(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/pulls" {
 			r, err := os.Open("testdata/github/pull.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
@@ -687,9 +688,9 @@ func TestGitHubOpenPullRequestHeadEmpty(t *testing.T) {
 
 		if r.URL.Path == "/repos/someone/something/pulls" {
 			r, err := os.Open("testdata/github/pull.json")
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			_, err = io.Copy(w, r)
-			require.NoError(t, err)
+			assert.NoError(t, err)
 			return
 		}
 
